@@ -147,7 +147,7 @@ ad = ('Alex Domingo', 'alex.domingo.toro@vub.be')
 # available remotes
 GIT_REMOTES = [
     'hpcugent',
-    'sisc-hpc',
+    'vub-hpc',
 ]
 
 # Regexp used to remove suffixes from scripts when installing(/packaging)
@@ -166,7 +166,7 @@ URL_GHUGENT_HPCUGENT = 'https://github.ugent.be/hpcugent/%(name)s'
 
 RELOAD_VSC_MODS = False
 
-VERSION = '0.17.5'
+VERSION = '0.17.12'
 
 log.info('This is (based on) vsc.install.shared_setup %s' % VERSION)
 log.info('(using setuptools version %s located at %s)' % (setuptools.__version__, setuptools.__file__))
@@ -697,14 +697,12 @@ class vsc_setup(object):
                 os.mkdir(setupper.REPO_LIB_DIR)
                 cleanup.append(setupper.REPO_LIB_DIR)
 
-            res = egg_info.finalize_options(self, *args, **kwargs)
+            egg_info.finalize_options(self, *args, **kwargs)
 
             # cleanup any diretcories created
             for directory in cleanup:
                 shutil.rmtree(directory)
 
-            return res
-
         def find_sources(self):
             """Default lookup."""
             egg_info.find_sources(self)
@@ -1032,12 +1030,11 @@ class vsc_setup(object):
                 __import__(DEFAULT_TEST_SUITE)
             self.reload_modules(DEFAULT_TEST_SUITE)
 
-            res = TestCommand.run_tests(self)
+            TestCommand.run_tests(self)
 
             # cleanup any diretcories created
             for directory in cleanup:
                 shutil.rmtree(directory)
-            return res
 
     @staticmethod
     def add_and_remove(alist, extra=None, exclude=None):
@@ -1432,7 +1429,7 @@ class vsc_setup(object):
 
         vsc_scripts = target.pop('vsc_scripts', True)
         if vsc_scripts:
-            candidates = self.generate_scripts()
+            candidates = self.generate_scripts(exclude=['__pycache__'])
             if candidates:
                 if 'scripts' in target:
                     old_scripts = target.pop('scripts', [])
@@ -1555,11 +1552,20 @@ class vsc_setup(object):
     def build_setup_cfg_for_bdist_rpm(target):
         """Generates a setup.cfg on a per-target basis.
 
-        Create [bdist_rpm] section with
+        Can be skipped by setting 'makesetupcfg' to False in setup.py
+
+        Creates [bdist_rpm] section with
             install_requires => requires
             provides => provides
             setup_requires => build_requires
 
+        Creates [metadata] section with
+            description-file => README file
+
+        Creates [install] section if needed,
+        if any of the following are specified via setup.py:
+            install-scripts => non-standard location for scripts/binaries
+
         @type target: dict
 
         @param target: specifies the options to be passed to setup()
@@ -1578,7 +1584,19 @@ class vsc_setup(object):
             sys.exit(1)
 
         klass = _fvs('build_setup_cfg_for_bdist_rpm')
-        txt = ["[bdist_rpm]"]
+
+        txt = []
+
+        # specify non-standard location for scripts/binaries, if specified
+        install_scripts = target.pop('install-scripts', None)
+        if install_scripts:
+            txt.extend([
+                '[install]',
+                'install-scripts = %s' % install_scripts,
+                '',
+            ])
+
+        txt.append("[bdist_rpm]")
         if 'install_requires' in target:
             txt.extend(["requires = %s" % (klass.sanitize(target['install_requires']))])
 
